@@ -28,8 +28,9 @@
 // END OF LICENSE HEADER
 
 // Extract youtube fmt parameter
-LinternaMagica.prototype.extract_youtube_fmt_parameter = function(data)
+LinternaMagica.prototype.extract_youtube_fmt_parameter = function()
 {
+    var data = this.script_data;
     var fmt_re = new RegExp (
 	"(\\\"|\\\'|\\\&)fmt_list"+
 	    "(\\\"|\\\')*(\\\=|\\\:|,)\\\s*(\\\"|\\\')*"+
@@ -155,7 +156,7 @@ LinternaMagica.prototype.create_youtube_links = function(fmt, fmt_url_map)
 		break;
 	    case '13':
 	    case '17':
-		nore_info += "MPEG-4 Visual, AAC";
+		more_info += "MPEG-4 Visual, AAC";
 		break;
 	    default:
 		more_info += " " + this._("Unkown encoding");
@@ -233,8 +234,9 @@ LinternaMagica.prototype.detect_youtube_flash_upgrade = function(object_data)
 }
 
 // Extract links data for youtube from fmt_url_map
-LinternaMagica.prototype.extract_youtube_fmt_url_map = function(data)
+LinternaMagica.prototype.extract_youtube_fmt_url_map = function()
 {
+    var data = this.script_data;
     var fmt_re = new RegExp (
 	"(\\\"|\\\'|\\\&|\\\&amp;)url_encoded_fmt_stream_map"+
 	    "(\\\"|\\\')*(\\\=|\\\:|,)\\\s*(\\\"|\\\')*"+
@@ -248,6 +250,9 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function(data)
 	this.log("LinternaMagica.extract_youtube_fmt_url_map:\n"+
 		 "Extracted fmt_url_map.",1);
 
+	this.log("LinternaMagica.extract_youtube_fmt_url_map:\n"+
+		 "RAW map variable:"+fmt,5);
+
 	// Hash with keys fmt_ids and values video URLs
 	var map = new Object();
 
@@ -262,14 +267,16 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function(data)
 	    // (itag=fmt_id)*url=URL&type=video/...&(itag=fmt_id)*
 	    var link = fmt[url].match(/url=([^&]+)/);
 	    var fmt_id = fmt[url].match(/itag=([0-9]+)/);
-
+	    var sig = fmt[url].replace(/\\u0026/g, '&').match(/sig=[^&]+/);
+		sig = sig[sig.length-1].replace(/sig/,'signature');
+	    
 	    if (fmt_id && link)
 	    {
 		links++;
 		link = unescape(link[link.length-1]);
 		link = link.split(/\\u0026/)[0];
 
-		map[fmt_id[fmt_id.length-1]] =  link;
+		map[fmt_id[fmt_id.length-1]] =  link+"&"+sig;
 	    }
 	}
 
@@ -303,6 +310,16 @@ function()
     return this.sites.__no_flash_plugin_installed.apply(this, [arguments]);
 }
 
+LinternaMagica.prototype.sites["youtube.com"].skip_script_processing =
+function()
+{
+    // See bug #108013:
+    // https://savannah.nongnu.org/support/index.php?108013
+    // Do not skip script processing in youtube. The default function
+    // might skip scripts in some browsers.
+    return true;
+}
+
 LinternaMagica.prototype.sites["youtube.com"].skip_link_extraction = function()
 {
     // Link extraction bloats FF in youtube:
@@ -333,8 +350,8 @@ function()
 
     this.extract_video_id_data = data;
 
-    var fmt = this.extract_youtube_fmt_parameter(data);
-    var maps = this.extract_youtube_fmt_url_map(data);
+    var fmt = this.extract_youtube_fmt_parameter();
+    var maps = this.extract_youtube_fmt_url_map();
 
     var hd_links = this.create_youtube_links(fmt, maps);
     var link = (hd_links && hd_links.length) ? hd_links : null;
@@ -362,6 +379,13 @@ function()
 	embed_id= embed_id[embed_id.length-1];
     }
 
+    if (!width || !height)
+    {
+	var p = document.getElementById("watch-player");
+	height = p ? p.clientHeight : null;
+	width  = p ? p.clientWidth : null;
+    }
+
     if (!width || !height)
     {
 	this.log("LinternaMagica.extract_object_from_script_youtube:\n"+
@@ -580,6 +604,42 @@ function(object_data)
 	    // will not be displaced.
 	    html5_wrapper.style.setProperty('display', "none", "important");
 
+	    // If the HTML5 player has a fallback CSS class and LM can
+	    // access it it means there is no other option for
+	    // playback. We take over the player.
+	    //
+	    // See bug 37630
+	    // https://savannah.nongnu.org/bugs/index.php?37630
+	    if (this.priority.html5 > this.priority.self)
+ 	    {
+		// It should be available, because it is used above in
+		// this function
+		id = id ? id : object_data.linterna_magica_id;
+
+		var lm = document.getElementById("linterna-magica-"+id);
+
+		if (!lm)
+		{
+		    return null;
+		}
+
+		lm.style.removeProperty("display");
+	    
+		// It should be available, because it is used above in
+		// this functon.
+		toggle_plugin = toggle_plugin  ? toggle_plugin :
+		    document.getElementById("linterna-magica-"+
+					    "toggle-plugin-"+id);
+
+		toggle_plugin.parentNode.removeChild(toggle_plugin);
+
+		toggle_plugin_header =
+		    document.getElementById("linterna-magica-"+
+					    "toggle-plugin-header-"+id);
+		
+		toggle_plugin_header.parentNode.removeChild(toggle_plugin_header);
+	    }
+	    
 	    // Hide site controls and video container. Should not
 	    // overlap with Linterna Magica now. Fixes the overlapping
 	    // of HTML5 player and LM.
